@@ -300,6 +300,9 @@ class Match(BASE):
     ladder = relationship('Ladder', foreign_keys=[ladder_id, platform_id], viewonly=True)
     rated = Column(Boolean)
     lobby_name = Column(String)
+    lobby_private = Column(Boolean)
+    lobby_opened = Column(DateTime)
+    server = Column(String)
     builtin_map_id = Column(Integer)
     builtin_map = relationship('Map', foreign_keys=[builtin_map_id, dataset_id], backref='matches', viewonly=True)
     map_size_id = Column(Integer, ForeignKey('map_sizes.id'), index=True)
